Installing PDF/PNG Export Functionality

## PNG/PDF Export

Export to PNG file formats requires the LibRSVG (SVG rendering) library or Inkscape to be installed.

Export to PDF requires LibRSVG, Inkscape or webkitToPDF to be installed.

## Installing LibRSVG

### Mac OS X

1. Install homebrew: follow the one-step installation directions here to install homebrew, the OS X package manager.
2. Install librsvg using homebrew: run the following command to install librsvg:

       brew install librsvg

### Linux (Ubuntu or similar)

1. Install librsvg: run the following command to install librsvg on ubuntu/debian/similar:

       sudo apt-get install librsvg2-dev

## Installing webkitToPDF (OS X only)

To install, download the latest binary file from the releases page, and move the application into your PATH. For example, after downloading and unzipping the application, use the following command to install the program (requires the administrator password):

    sudo mv webkitToPDF /usr/bin